#!/usr/bin/perl -wT
# This cgi-script translates webpages to the dialect spoken in Berlin, Germany.
#
# 02.01.2004: Modified by Josef Spillner <dr_maux@users.sourceforge.net>:
# Removed CGI mode
#
# Copyright (C) 2002-2003 Ramiro Gmez <ramiro@rahoo.de>
#
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
use strict;

# If you need to specify additional paths to perl modules, do it here, e.g.:
# use lib qw(/home/pub/lib/perl5/site_perl/5.6.1);
#use Carp;

# locale settings for \w matching ,,
use locale;
use POSIX 'locale_h';
setlocale(LC_CTYPE, 'de_DE') or die "Invalid locale";

# "translate" to Berlin's dialect 
sub substitute {
    my $line = shift;
    my $vowel = 'aeiou';
    #my $consonant = 'bcdfghjklmnpqrstvwxyz';
    
    # translate only the plural form of a word, if its case 
    # differs from the case of the translation 
    my %subst_words = ('An der' => 'Anna',
		       'an der' => 'anna',
		       'An die' => 'Anne',
		       'an die' => 'anne',
		       'Auch' => 'Och',
		       'auch' => 'och',
		       'Buche' => 'Plautzen',
		       'Beamten' => 'Stubenpisser',
		       'Beamter' => 'Stubenpisser',
		       'Beine' => 'Kackstelzen',
		       'Brder' => 'Atzen',
		       'Du' => 'De',
		       'du' => 'de',
		       'Elektriker' => 'Strippenzieher',
		       'Finger' => 'Wichsgriffel',
		       'Flasche' => 'Pulle',
		       'Flaschen' => 'Pullen',
		       'Frau' => 'Butze',
		       'Frauen' => 'Butzen',
		       'Freundin' => 'Ficke',
		       'Frisur' => 'Fettpeitsche',
		       'Fe' => 'Quanten',
		       'Gesellschaft' => 'Blase',
		       'Gesichter' => 'Fratzen',
		       'Hand' => 'Pfote',
		       'Hnde' => 'Wichsgriffel',
		       'Harre' => 'Peden',
		       'Herzen' => 'Cognacpumpen',
		       'Hitze' => 'Affenhitze',
		       'Hund' => 'Kter',
		       'Hunde' => 'Kter',
		       'Ich' => 'Ick',
		       'ich' => 'ick',
		       'In der' => 'Inna',
		       'in der' => 'inna',
		       'In die' => 'Inne',
		       'in die' => 'inne',
		       'Kinder' => 'Ableja',
		       'Kleidung' => 'Klamotten',
		       'Kneipe' => 'Destille',
		       'Kneipen' => 'Destillen',
		       'Lokale' => 'Destillen',
		       'Nein' => 'Nee',
		       'nein' => 'nee',
		       'Nichts' => 'Nischt',
		       'nichts' => 'nischt',
		       'Mnder' => 'Futtaluken',
		       'Mutter' => 'Olle',
		       'Parfum' => 'Eau de Mief',
		       'Polizei' => 'Polente',
		       'Polizist' => 'Bulle',
		       'Polizisten' => 'Bullen',
		       'Rollstuhl' => 'AOK-Choppa',
		       'Rollsthle' => 'AOK-Choppa',
		       'Schwester' => 'Atze',
		       'Schwestern' => 'Atzen',
		       'Vater' => 'Oller',
		       'Verwandtschaft' => 'Blase',
		       'Was' => 'Wat',
		       'was' => 'wat',
		       'Wirtshuser' => 'Destillen',
		       'Zigarette' => 'Zippe',
		       'Zigaretten' => 'Zippen');

    # substitute all keys of %subst_words with the corresponding values
    map ($line =~ s/(\b)$_(\b)/$1$subst_words{$_}$2/g, keys %subst_words);
    
    $line =~ s|(\b)Auf|$1Uff|g;
    $line =~ s|(\b)auf|$1uff|g;
    $line =~ s|(\w{2,})er([^$vowel])|$1a$2|g;
    $line =~ s|([$vowel])r([^$vowel])|$1a$2|g;
    $line =~ s|([$vowel])hr(\b)|$1a$2|g;
    $line =~ s|([^n])g([r$vowel])|$1j$2|g;
    $line =~ s/([^$vowel][^n])g(\b)/$1ch$2/g;
    $line =~ s|(\b)g([^l])|$1j$2|g;
    $line =~ s|(\b)G([^l])|$1J$2|g;
    
    return $line;
}

while(<STDIN>){
	print substitute($_);
}

