# -*- coding: utf-8 -*-

"""
Help processing of German words.
"""

import re, string

re_vowels = re.compile (r"au|eu|ai|ei|ie|oi|aa|ee|oo|[aeiouyäöü]", re.IGNORECASE)

re_word   = re.compile (r"\w+", re.LOCALE)
#re_word   = re.compile (r"[äöüÄÖÜß\w]+")	# LOCALE flag seems not to include German umlauts to \w shortcut
# if LOCALE doesn't work properly, \b won't do as well
#re_word_apo   = re.compile (r"['`´äöüÄÖÜß\w]+")
re_word_apo   = re.compile (r"['`´\w]+")

class WordProcessor:
	def __init__(self,proc):
		self.proc = proc

	def process_capital_word(self,word):
		"""
		Translate a word with probably beginning capital.

		After translation the word is converted back
		to the original capitalization.
		"""
		if word[0] == string.upper(word[0]):	# word[0] in string.uppercase
			return string.capitalize(self.proc(string.lower(word)))
		else:	# can only happen with the first part in a word cluster
			return self.proc(word)

	def process_word(self,mt):
		"""
		Decompose a word into subwords.
		
		E.g. "MultipleWordsInOne" -> ["Multiple", "Words", "In", "One"]
		"""
		word = mt.group()
		#print word
		if word == string.lower(word):	# lower case words
			return self.proc(word)
		elif word == string.upper(word):	# all upper case, probably abbreviations
			return string.upper(self.proc(string.lower(word)))
		else:	# words which are not fully lower case or upper case are splitted before every capital
			part = ""
			result_word = ""
			for c in word:
				# "!= lower()" is used instead of "== upper()" to let an apostrophe look like a lower case letter
				if c != string.lower(c) and part != "":
					result_word = result_word + self.process_capital_word(part)
					part = ""
				part = part + c
			if part != "":
				result_word = result_word + self.process_capital_word(part)
			return result_word
			return self.proc(mt.group())

def process_words(text,proc,re_word_int=re_word):
	"""
	Process the contents of a word using the procedure 'proc'.
	
	A word processor using the translator procedure 'proc'
	is generated and used for substituting word components
	by their translations.
	"""
	return re_word_int.sub(WordProcessor(proc).process_word, text)

